FitMultiCell
============

.. figure:: https://gitlab.com/fitmulticell/fit/raw/main/doc/logo/logo_long.svg.png
   :alt: FitMultiCell logo
   :width: 60 %
   :align: center

|docs| |pypi|

Fitting of multi-cellular models combining the tools `morpheus <https://gitlab.com/morpheus.lab/morpheus>`_ and `pyABC <https://github.com/icb-dcm/pyabc>`_.

- **Documentation:** https://fitmulticell.readthedocs.io
- **Contact:** https://fitmulticell.readthedocs.io/en/latest/contact.html
- **Source code:** https://gitlab.com/fitmulticell/fit
- **Examples:** https://fitmulticell.readthedocs.io/en/latest/example.html
- **Bug reports:** https://gitlab.com/fitmulticell/fit/issues

.. |docs| image:: https://readthedocs.org/projects/fitmulticell/badge/?version=latest
   :target: http://fitmulticell.readthedocs.io/en/latest/
   :alt: Docs

.. |pypi| image:: https://badge.fury.io/py/fitmulticell.svg
   :target: https://badge.fury.io/py/fitmulticell
   :alt: PyPI
